<?php
/**
 * Kids Education Pro Testimonial Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add testimonial enable section
$wp_customize->add_section( 'kids_education_pro_testimonial', array(
	'title'             => esc_html__( 'Testimonial','kids-education-pro' ),
	'description'       => esc_html__( 'Testimonial section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add testimonial enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_enable]', array(
	'default'           => $options['testimonial_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_enable]', array(
	'label'             => esc_html__( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add no of testimonial content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_content_type]', array(
	'default'           => $options['testimonial_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'select',
	'choices'			=> kids_education_pro_testimonial_content_type(),
	'active_callback'	=> 'kids_education_pro_is_testimonial_section_active',
) );

// Add no of testimonial content setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_count]', array(
	'default'           => $options['testimonial_count'],
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'No of Testimonials', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'number',
	'input_attrs'		=> array (
		'min'	=> 2,
		'max'	=> 10,
		'style'	=> 'width:100px'
		),
	'active_callback'	=> 'kids_education_pro_is_testimonial_section_active',
) );

// Add testimonial slide dragable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_dragable]', array(
	'default'           => $options['testimonial_dragable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_dragable]', array(
	'label'             => esc_html__( 'Enable Slider Dragable', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_testimonial_post_active',
) );

// Add testimonial slide pager setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_pager]', array(
	'default'           => $options['testimonial_pager'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_pager]', array(
	'label'             => esc_html__( 'Enable Slider Pager', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_testimonial_section_active',
) );

// Add testimonial slide pause on hover setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_pauseonhover]', array(
	'default'           => $options['testimonial_pauseonhover'],
	'sanitize_callback' => 'kids_education_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_pauseonhover]', array(
	'label'             => esc_html__( 'Enable Pause on Hover', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_testimonial',
	'type'              => 'checkbox',
	'active_callback'	=> 'kids_education_pro_is_testimonial_section_active',
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_background_image]', array(
	'default'           => $options['testimonial_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_background_property]', array(
	'default'           => $options['testimonial_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[testimonial_background_property]', array(
	'label'           	=> esc_html__( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_testimonial',
	'active_callback' 	=> 'kids_education_pro_is_testimonial_post_active',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => esc_html__( 'Background Image', 'kids-education-pro' ),
		'background_color' => esc_html__( 'Background Color', 'kids-education-pro' ), 
	)
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[testimonial_background_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_testimonial',
		'active_callback' => 'kids_education_pro_is_testimonial_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[testimonial_background_color]', array(
	'default'           => $options['testimonial_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[testimonial_background_color]', array(
	'label'        => esc_html__( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_testimonial',
	'active_callback' => 'kids_education_pro_is_testimonial_background_property_color',
) ) );