<?php
/**
 * Jetpack Compatibility File.
 *
 * @link https://jetpack.com/
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

/**
 * Jetpack setup function.
 *
 * See: https://jetpack.com/support/infinite-scroll/
 * See: https://jetpack.com/support/responsive-videos/
 */

function kids_education_pro_jetpack_setup() {
	$options = kids_education_pro_get_theme_options();

	$pagination_type	= isset( $options['pagination_type'] ) ? $options['pagination_type'] : '';
	if ( in_array( $pagination_type, array( 'infinite-click', 'infinite-scroll' ) ) ) {
		if ( 'infinite-click' == $pagination_type ) {
			$type = 'click';
		} elseif( 'infinite-scroll' == $pagination_type ){
			$type = 'scroll';
		}
		// Add theme support for Infinite Scroll.
		add_theme_support( 'infinite-scroll', array(
			'type'      => $type,
			'container' => 'two-column',
			'render'    => 'kids_education_pro_infinite_scroll_render',
			'wrapper'   => false,
			'footer'    => false,
		) );
	}

	// Add theme support for Responsive Videos.
	add_theme_support( 'jetpack-responsive-videos' );
}
add_action( 'after_setup_theme', 'kids_education_pro_jetpack_setup' );

/**
 * Custom render function for Infinite Scroll or Infinite Click.
 */
function kids_education_pro_infinite_scroll_render() {
	$int = 1;

	$tp_education_post_type = array( 'event', 'course', 'excursion', 'team', 'class' );
	$post_type = get_query_var( 'post_type' );

	$count = get_option( 'posts_per_page' );
	$i = 1;
	
	while ( have_posts() ) {
		the_post();
		if ( is_search() && in_array( $post_type, $tp_education_post_type ) ) :
			if ( has_action( 'tp_education_search_content_action' ) ) :
				/**
				 * Hook - tp_education_search_content_action.
				 *
				 * @hooked tp_education_search_content -  10
				 */
				do_action( 'tp_education_search_content_action' );
			endif;
		elseif ( is_archive() && ( is_post_type_archive( 'event' ) || is_tax('event-category') ) ) :
			if ( has_action( 'tp_education_archive_event_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_event_content_action.
				 *
				 * @hooked tp_education_archive_event_content -  10
				 */
				do_action( 'tp_education_archive_event_content_action' );
			endif;
		elseif ( is_archive() && ( is_post_type_archive( 'class' ) || is_tax('class-category') ) ) :
			if ( has_action( 'tp_education_archive_class_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_class_content_action.
				 *
				 * @hooked tp_education_archive_class_content -  10
				 */
				do_action( 'tp_education_archive_class_content_action' );
			endif;
		elseif ( is_archive() && ( is_post_type_archive( 'course' ) || is_tax('course-category') ) ) :
			if ( has_action( 'tp_education_archive_course_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_course_content_action.
				 *
				 * @hooked tp_education_archive_course_content -  10
				 */
				do_action( 'tp_education_archive_course_content_action' );
			endif;
		elseif ( is_archive() && ( is_post_type_archive( 'team' ) || is_tax('team-category') ) ) :
			if ( has_action( 'tp_education_archive_team_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_team_content_action.
				 *
				 * @hooked tp_education_archive_team_content -  10
				 */
				do_action( 'tp_education_archive_team_content_action' );
			endif;
		elseif ( is_archive() && ( is_post_type_archive( 'excursion' ) || is_tax('excursion-category') ) ) :
			if ( has_action( 'tp_education_archive_excursion_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_excursion_content_action.
				 *
				 * @hooked tp_education_archive_excursion_content -  10
				 */
				do_action( 'tp_education_archive_excursion_content_action' );
			endif;
		elseif ( is_archive() && is_post_type_archive( 'testimonial' ) ) :
			if ( has_action( 'tp_education_archive_testimonial_content_action' ) ) :
				/**
				 * Hook - tp_education_archive_testimonial_content_action.
				 *
				 * @hooked tp_education_archive_testimonial_content -  10
				 */
				do_action( 'tp_education_archive_testimonial_content_action' );
			endif;
		elseif ( is_home() ) :
			get_template_part( 'template-parts/content', 'blog' );

		elseif ( is_search() ) :
			get_template_part( 'template-parts/content', 'search' );
			if( $count % 2 == 0 ) :
				if ( $i % 2 == 0 ) :
				echo '<div class="clear"></div>';
				endif;
			elseif( $count % 2 == 1 ) :
				if ( $int % 2 == 1  || ( $int > $count && ( $int % 2 == 1 ) ) ) :
				echo '<div class="clear"></div>';
				endif;
			endif;
			$i++;
			if( $count % 2 == 1 ) :
				$int = $i;
				if ( $count * 2 == $int ) $int = 1;
			endif;
			$int++;
		else :
			get_template_part( 'template-parts/content', get_post_format() );
			if( $count % 2 == 0 ) :
				if ( $i % 2 == 0 ) :
				echo '<div class="clear"></div>';
				endif;
			elseif( $count % 2 == 1 ) :
				if ( $int % 2 == 1  || ( $int > $count && ( $int % 2 == 1 ) ) ) :
				echo '<div class="clear"></div>';
				endif;
			endif;
			$i++;
			if( $count % 2 == 1 ) :
				$int = $i;
				if ( $count * 2 == $int ) $int = 1;
			endif;
			$int++;
		endif;
	}
}